@@ -20,35 +20,29 @@
 #' # plot
 #' plot(bins)
 #'
+#'
 #' @export
 #'
 rbin_equal_length <- function(data = NULL, response = NULL, predictor = NULL, bins = 10, include_na = TRUE) UseMethod("rbin_equal_length")
 
 #' @export
 #'
-rbin_equal_length <- function(data = NULL, response = NULL, predictor = NULL, bins = 10, include_na = TRUE) {
+rbin_equal_length.default <- function(data = NULL, response = NULL, predictor = NULL, bins = 10, include_na = TRUE) {
 
-  resp <- rlang::enquo(response)
-  pred <- rlang::enquo(predictor)
+  resp <- deparse(substitute(response))
+  pred <- deparse(substitute(predictor))
 
-  var_names <-
-    data %>%
-    dplyr::select(!! resp, !! pred) %>%
-    names()
+  var_names <- names(data[, c(resp, pred)])
+  prep_data <- data[, c(resp, pred)]
 
-    if (include_na) {
-    bm <-
-      data %>%
-      dplyr::select(!! resp, !! pred) %>%
-      magrittr::set_colnames(c("response", "predictor"))
+  if (include_na) {
+    bm <- prep_data
   } else {
-    bm <-
-      data %>%
-      dplyr::select(!! resp, !! pred) %>%
-      dplyr::filter(!is.na(!! resp), !is.na(!! pred)) %>%
-      magrittr::set_colnames(c("response", "predictor"))
+    bm <- na.omit(prep_data)
   }
 
+  colnames(bm) <- c("response", "predictor")
+
   bm$bin    <- NA
   byd       <- bm$predictor
   l_freq    <- el_freq(byd, bins)
@@ -63,23 +57,23 @@ rbin_equal_length <- function(data = NULL, response = NULL, predictor = NULL, bi
   fbin2     <- f_bin(u_freq)
   intervals <- create_intervals(sym_sign, fbin2)
 
-  if (include_na) {
+ if (include_na) {
 
-    na_present <-
-      k %>%
-      nrow() %>%
-      magrittr::is_greater_than(bins)
+    na_present <- nrow(k) > bins
 
     if (na_present) {
-      intervals <- dplyr::add_row(intervals, cut_point = 'NA')
+      intervals <- rbind(intervals, cut_point = 'NA')
     }
 
   }
 
-  result    <- list(bins = dplyr::bind_cols(intervals, k), method = "Equal Length", vars = var_names,
-                    lower_cut = l_freq, upper_cut = u_freq)
+  result <- list(bins      = cbind(intervals, k),
+                 method    = "Equal Length",
+                 vars      = var_names,
+                 lower_cut = l_freq,
+                 upper_cut = u_freq)
 
-  class(result) <- c("rbin_equal_length", "tibble", "data.frame")
+  class(result) <- c("rbin_equal_length")
   return(result)
 
 }
@@ -91,10 +85,8 @@ print.rbin_equal_length <- function(x, ...) {
 
   rbin_print(x)
   cat("\n\n")
-  x %>%
-    magrittr::use_series(bins) %>%
-    dplyr::select(cut_point, bin_count, good, bad, woe, iv, entropy) %>%
-    print()
+  print(x$bins[c('cut_point', 'bin_count', 'good', 'bad', 'woe', 'iv', 'entropy')])
+
 }
 
 #' @rdname rbin_equal_length
@@ -103,12 +95,13 @@ print.rbin_equal_length <- function(x, ...) {
 plot.rbin_equal_length <- function(x, print_plot = TRUE, ...) {
 
   p <- plot_bins(x)
+
   if (print_plot) {
     print(p)
-  } else {
-    return(p)
   }
 
+  return(p)
+
 }
 
 el_freq <- function(byd, bins) {
