@@ -32,34 +32,26 @@ rbin_manual <- function(data = NULL, response = NULL, predictor = NULL, cut_poin
 
 #' @export
 #'
-rbin_manual <- function(data = NULL, response = NULL, predictor = NULL, cut_points = NULL, include_na = TRUE) {
+rbin_manual.default <- function(data = NULL, response = NULL, predictor = NULL, cut_points = NULL, include_na = TRUE) {
 
-  resp <- rlang::enquo(response)
-  pred <- rlang::enquo(predictor)
+  resp <- deparse(substitute(response))
+  pred <- deparse(substitute(predictor))
 
-  var_names <-
-    data %>%
-    dplyr::select(!! resp, !! pred) %>%
-    names()
+  var_names <- names(data[c(resp, pred)])
+  prep_data <- data[c(resp, pred)]
 
   if (include_na) {
-  	bm <-
-      data %>%
-      dplyr::select(!! resp, !! pred) %>%
-      magrittr::set_colnames(c("response", "predictor"))
+    bm <- prep_data
   } else {
-  	bm <-
-      data %>%
-      dplyr::select(!! resp, !! pred) %>%
-      dplyr::filter(!is.na(!! resp), !is.na(!! pred)) %>%
-      magrittr::set_colnames(c("response", "predictor"))
+    bm <- na.omit(prep_data)
   }
 
+  colnames(bm) <- c("response", "predictor")
+
   bm$bin    <- NA
   byd       <- bm$predictor
   l_freq    <- append(min(byd, na.rm = TRUE), cut_points)
   u_freq    <- c(cut_points, (max(byd, na.rm = TRUE) + 1))
-  # u_freq    <- purrr::prepend((max(byd, na.rm = TRUE) + 1), cut_points)
   bins      <- length(cut_points) + 1
 
   for (i in seq_len(bins)) {
@@ -73,21 +65,21 @@ rbin_manual <- function(data = NULL, response = NULL, predictor = NULL, cut_poin
 
   if (include_na) {
 
-  	na_present <-
-		  k %>%
-		  nrow() %>%
-		  magrittr::is_greater_than(bins)
+    na_present <- nrow(k) > bins
 
-		if (na_present) {
-		  intervals <- dplyr::add_row(intervals, cut_point = 'NA')
-		}
+    if (na_present) {
+      intervals <- rbind(intervals, cut_point = 'NA')
+    }
 
   }
 
-  result    <- list(bins = dplyr::bind_cols(intervals, k), method = "Manual", vars = var_names,
-                    lower_cut = l_freq, upper_cut = u_freq)
+  result <- list(bins = cbind(intervals, k),
+                 method = "Manual",
+                 vars = var_names,
+                 lower_cut = l_freq,
+                 upper_cut = u_freq)
 
-  class(result) <- c("rbin_manual", "tibble", "data.frame")
+  class(result) <- c("rbin_manual")
   return(result)
 
 }
@@ -99,10 +91,7 @@ print.rbin_manual <- function(x, ...) {
 
   rbin_print(x)
   cat("\n\n")
-  x %>%
-    magrittr::use_series(bins) %>%
-    dplyr::select(cut_point, bin_count, good, bad, woe, iv, entropy) %>%
-    print()
+  print(x$bins[c('cut_point', 'bin_count', 'good', 'bad', 'woe', 'iv', 'entropy')])
 }
 
 #' @rdname rbin_manual
@@ -111,10 +100,11 @@ print.rbin_manual <- function(x, ...) {
 plot.rbin_manual <- function(x, print_plot = TRUE, ...) {
 
   p <- plot_bins(x)
+
   if (print_plot) {
     print(p)
-  } else {
-    return(p)
   }
 
+  return(p)
+
 }
