@@ -10,6 +10,8 @@
 #' @param min_val the low border, all values being lower than this will be replaced by this value. The default is set to the 5 percent quantile of predictor.
 #' @param max_val the high border, all values being larger than this will be replaced by this value. The default is set to the 95 percent quantile of predictor.
 #' @param include_na logical; if \code{TRUE}, a separate bin is created for missing values.
+#' @param remove_na logical; if \code{TRUE} NAs will removed while calculating quantiles
+#' @param type an integer between 1 and 9 selecting one of the nine quantile algorithms detailed in \code{quantile()} to be used.
 #' @param x An object of class \code{rbin_winsorize}.
 #' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #' @param ... further arguments passed to or from other methods.
@@ -25,59 +27,46 @@
 #'
 #' @export
 #'
-rbin_winsorize <- function(data = NULL, response = NULL, predictor = NULL, bins = 10,
-	winsor_rate = 0.05, min_val = NULL, max_val = NULL, include_na = TRUE) UseMethod("rbin_winsorize")
+rbin_winsorize <- function(data = NULL, response = NULL, predictor = NULL,
+                                   bins = 10, include_na = TRUE, winsor_rate = 0.05,
+                                   min_val = NULL, max_val = NULL, type = 7,
+                                   remove_na = TRUE) UseMethod("rbin_winsorize")
 
 
 #' @export
 #'
-rbin_winsorize.default <- function(data = NULL, response = NULL, predictor = NULL, bins = 10,
-	winsor_rate = 0.05, min_val = NULL, max_val = NULL, include_na = TRUE) {
+rbin_winsorize.default <- function(data = NULL, response = NULL, predictor = NULL,
+                                   bins = 10, include_na = TRUE, winsor_rate = 0.05,
+                                   min_val = NULL, max_val = NULL, type = 7,
+                                   remove_na = TRUE) {
 
-  resp <- rlang::enquo(response)
-  pred <- rlang::enquo(predictor)
+  resp <- deparse(substitute(response))
+  pred <- deparse(substitute(predictor))
 
   probs_min <- 0 + winsor_rate
   probs_max <- 1 - winsor_rate
 
-  var_names <-
-    data %>%
-    dplyr::select(!! resp, !! pred) %>%
-    names()
+  var_names <- names(data[, c(resp, pred)])
+  prep_data <- data[, c(resp, pred)]
+  colnames(prep_data) <- c("response", "predictor")
 
   if (include_na) {
-    bm <-
-      data %>%
-      dplyr::select(!! resp, !! pred) %>%
-      magrittr::set_colnames(c("response", "predictor")) %>%
-      dplyr::mutate(
-        predictor2 = DescTools::Winsorize(
-          x      = predictor,
-          minval = min_val,
-          maxval = max_val,
-          probs  = c(probs_min, probs_max),
-          na.rm  = TRUE
-        )
-      ) %>%
-      dplyr::select(response, predictor = predictor2)
+    bm_data <- prep_data
   } else {
-    bm <-
-      data %>%
-      dplyr::select(!! resp, !! pred) %>%
-      dplyr::filter(!is.na(!! resp), !is.na(!! pred)) %>%
-      magrittr::set_colnames(c("response", "predictor")) %>%
-      dplyr::mutate(
-        predictor2 = DescTools::Winsorize(
-          x      = predictor,
-          minval = min_val,
-          maxval = max_val,
-          probs  = c(probs_min, probs_max),
-          na.rm  = TRUE
-        )
-      ) %>%
-      dplyr::select(response, predictor = predictor2)
+    bm_data <- na.omit(prep_data)
   }
 
+  bm_data$predictor2 <- winsor(
+    x       = prep_data$predictor,
+    min_val = min_val,
+    max_val = max_val,
+    probs   = c(probs_min, probs_max),
+    na.rm   = remove_na,
+    type    = type)
+
+  bm <- bm_data[c('response', 'predictor2')]
+  colnames(bm) <- c("response", "predictor")
+
   bm$bin    <- NA
   byd       <- bm$predictor
   l_freq    <- el_freq(byd, bins)
@@ -94,21 +83,21 @@ rbin_winsorize.default <- function(data = NULL, response = NULL, predictor = NUL
 
   if (include_na) {
 
-    na_present <-
-      k %>%
-      nrow() %>%
-      magrittr::is_greater_than(bins)
+    na_present <- nrow(k) > bins
 
     if (na_present) {
-      intervals <- dplyr::add_row(intervals, cut_point = 'NA')
+      intervals <- rbind(intervals, cut_point = 'NA')
     }
 
   }
 
-  result    <- list(bins = dplyr::bind_cols(intervals, k), method = "Winsorize", vars = var_names,
-                    lower_cut = l_freq, upper_cut = u_freq)
+  result <- list(bins = cbind(intervals, k),
+                 method = "Winsorize",
+                 vars = var_names,
+                 lower_cut = l_freq,
+                 upper_cut = u_freq)
 
-  class(result) <- c("rbin_winsorize", "tibble", "data.frame")
+  class(result) <- c("rbin_winsorize")
   return(result)
 
 }
@@ -120,10 +109,7 @@ print.rbin_winsorize <- function(x, ...) {
 
   rbin_print(x)
   cat("\n\n")
-  x %>%
-    magrittr::use_series(bins) %>%
-    dplyr::select(cut_point, bin_count, good, bad, woe, iv, entropy) %>%
-    print()
+  print(x$bins[c('cut_point', 'bin_count', 'good', 'bad', 'woe', 'iv', 'entropy')])
 }
 
 #' @rdname rbin_winsorize
@@ -132,10 +118,11 @@ print.rbin_winsorize <- function(x, ...) {
 plot.rbin_winsorize <- function(x, print_plot = TRUE, ...) {
 
   p <- plot_bins(x)
+
   if (print_plot) {
     print(p)
-  } else {
-    return(p)
   }
 
+  return(p)
+
 }
